/*
** Module   : SessionUtils.java
** Abstract : Defines APIs used to access the SESSION attributes and methods.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 CA  20130112 Created initial version.
*/

package com.goldencode.p2j.util;

import com.goldencode.p2j.ui.LogicalTerminal;
import com.goldencode.proxy.StaticProxy;

/**
 * This class provides implementation for SESSION attributes and methods.
 * Mainly, the APIs implemented here are defined in the {@link CommonSession}
 * interface (or one of its super interfaces) and are not statically 
 * implemented by the classes used by the {@link #asHandle()}.
 */
public class SessionUtils
{
   /**
    * Get a the instance for the SESSION system handle.  Is obtained using
    * a call to the {@link StaticProxy#obtain(Class, Class[])}, using the
    * {@link CommonSession} interface and its methods implemented by these
    * classes: {@link SessionUtils}, {@link EnvironmentOps}, {@link date},
    * {@link LogicalTerminal}, {@link ProcedureManager}.
    * 
    * @return   See above.
    */
   public static handle asHandle()
   {
      Class[] classes = 
      {
         SessionUtils.class,
         EnvironmentOps.class,
         date.class,
         LogicalTerminal.class,
         ProcedureManager.class
      };
      CommonSession proxy = StaticProxy.obtain(CommonSession.class, 
                                               classes);
      return new handle(proxy);
   }
   
   /**
    * Get the type of its associated handle.
    * 
    * @return   Always return the PSEUDO-WIDGET value.
    */
   public static character getType()
   {
      return new character("PSEUDO-WIDGET");
   }
   
   /**
    * Implementation for the {@link WrappedResource#isValid()} API.
    * 
    * @return   Always true.
    */
   public static boolean isValid()
   {
      return true;
   }
   
   /**
    * Implementation for the {@link WrappedResource#isUnknown()} API.
    * 
    * @return   Always false.
    */
   public static boolean isUnknown()
   {
      return false;
   }
   
   /**
    * API needed to implement read-only attribute assignment (a 4GL 
    * "feature").
    * 
    * @param    attribute
    *           The attribute's name.
    *           
    * @see      handle#readOnlyError(handle, String)
    */
   public static void readOnlyError(String attribute)
   {
      handle.readOnlyError(asHandle(), attribute);
   }
}